Coverage for autoapp.py: 0%

# Coverage for autoapp.py : 0%

## 3 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 sys.path.append(os.getcwd())

2 from app import create_app

3

4

5# CONFIG_JSON_PATH = os.path.dirname(os.path.abspath(__file__))

6

7

8# try:

9# if not os.path.exists("config.json"):

10# trycopy("config_demo.json", "config.json")

11# except Exception as e:

12# print(e)

13# sys.exit(1)

14

15# with open(os.path.join(CONFIG_JSON_PATH, "config.json")) as f:

16# config_json = json.load(f)

17

18# environment = config_json["environment"]

19 app = create_app("production")